import setuptools

# Each Python project should have pyproject.toml or setup.py
# TODO: Please create pyproject.toml instead of setup.py (delete the setup.py)
# used by python -m build
# ```python -m build``` needs pyproject.toml or setup.py
# The need for setup.py is changing as of poetry 1.1.0 (including current pre-release) as we have moved away
# from needing to generate a setup.py file to enable editable installs - We might able to delete this file in the near future
setuptools.setup(
     name='profile-reddit-restapi-imp-local',  
     version='0.0.28',  # https://pypi.org/project/profile-reddit-restapi-imp-local/
     author="Circles",
     author_email="info@circles.life",
     description="PyPI Package for Circles profile-local-reddit-restapi-imp Local/Remote Python",
     # TODO: Please update the long description and delete this line    
     long_description="This is a package for sharing common XXX function used in different repositories",
     long_description_content_type="text/markdown",
     url="https://github.com/circles-zone/profile-local-reddit-restapi-imp-python-package",
     packages=setuptools.find_packages(),
     classifiers=[
         "Programming Language :: Python :: 3",
         "License :: Other/Proprietary License",
         "Operating System :: OS Independent",
     ],
     install_requires=[
        'praw>=7.4.0',
        'tqdm>=4.64.1',
        'database-without-orm-local>=0.0.11',
        'importer-local>=0.0.6',
        'logzio-python-handler>=4.1.0',
        'profile-local>=0.0.11',
        'url-local>=0.0.22',
        'python-dotenv>=1.0.0',
        'logger-local>=0.0.46',
        'entity-type-local>=0.0.13',
        'group-remote>=0.0.85',
        'source-data-local>=0.0.3'
        ]
)



from logger_local.Logger import Logger
from logger_local.LoggerComponentEnum import LoggerComponentEnum

import praw
import sys
import os
from dotenv import load_dotenv

load_dotenv()

# Add the parent directory to the path so we can import the script
script_directory = os.path.dirname(os.path.abspath(__file__))
sys.path.append(os.path.join(script_directory, '..'))
from profile_reddit_restapi_imp_python_package.search_reddit import Reddit                            # noqa: E402
from profile_reddit_restapi_imp_python_package.handler import RedditImporter                          # noqa: E402
from profile_reddit_restapi_imp_python_package.ProfileRedditConstants import (                        # noqa: E402
    PROFILE_REDDIT_LOCAL_PYTHON_PACKAGE_COMPONENT_ID,
    PROFILE_REDDIT_LOCAL_PYTHON_PACKAGE_COMPONENT_NAME
)

object_to_insert = {
    'component_id': PROFILE_REDDIT_LOCAL_PYTHON_PACKAGE_COMPONENT_ID,
    'component_name': PROFILE_REDDIT_LOCAL_PYTHON_PACKAGE_COMPONENT_NAME,
    'component_category': LoggerComponentEnum.ComponentCategory.Code.value,
    'testing_framework': LoggerComponentEnum.testingFramework.pytest.value,
    'developer_email': 'yoav.e@circ.zone'
}

logger = Logger.create_logger(object=object_to_insert)


def test_authenticate_reddit():
    logger.start()
    reddit = Reddit()._authenticate_reddit()

    result = isinstance(reddit, praw.Reddit)
    logger.end(object={'result': result})
    assert result


def test_get_subreddit_and_query():
    FUNNY = "funny"
    USER_COUNT = 10
    logger.start()
    request = {"subreddit_name": FUNNY, "user_count": USER_COUNT}
    reddit_object = Reddit()
    subreddit_name, num = reddit_object.get_subreddit_and_query(request=request)
    logger.info(f"subreddit_name {subreddit_name}")
    logger.info(f"num {num}")
    assert subreddit_name == "funny"
    assert num == 10
    logger.end()


def test_handle():
    logger.start()
    event_json = {
                    "subreddit_name": "funny",
                    "user_count": 1
                 }
    reddit_object = RedditImporter()
    reddit_object.handle(event_json)
    logger.end()
